@@ -49,7 +49,11 @@ class FileChooserEntry(Gtk.Box):
         warn_if_non_empty=False,
         warn_if_ntfs=False
     ):
-        super().__init__(orientation=Gtk.Orientation.VERTICAL, spacing=12, visible=True)
+        super().__init__(
+            orientation=Gtk.Orientation.VERTICAL,
+            spacing=0,
+            visible=True
+        )
         self.title = title
         self.action = action
         self.path = os.path.expanduser(path) if path else None
@@ -71,7 +75,7 @@ class FileChooserEntry(Gtk.Box):
         box = Gtk.Box(spacing=6, visible=True)
         box.pack_start(self.entry, True, True, 0)
         box.add(browse_button)
-        self.add(box)
+        self.pack_start(box, False, False, 0)
 
     def get_text(self):
         """Return the entry's text"""
@@ -90,12 +94,11 @@ class FileChooserEntry(Gtk.Box):
         return completion
 
     def get_filechooser_dialog(self):
-        """Return an instance of a FileChooserDialog configured for this widget"""
-        dialog = Gtk.FileChooserDialog(title=self.title, transient_for=None, action=self.action)
-        dialog.add_buttons(_("_Cancel"), Gtk.ResponseType.CLOSE, _("_OK"), Gtk.ResponseType.OK)
+        """Return an instance of a FileChooserNative configured for this widget"""
+        dialog = Gtk.FileChooserNative.new(self.title, None, self.action, _("_OK"), _("_Cancel"))
         dialog.set_create_folders(True)
         dialog.set_current_folder(self.get_default_folder())
-        dialog.connect("response", self.on_select_file)
+        dialog.connect("response", self.on_select_file, dialog)
         return dialog
 
     def get_default_folder(self):
@@ -112,7 +115,7 @@ class FileChooserEntry(Gtk.Box):
     def on_browse_clicked(self, _widget):
         """Browse button click callback"""
         file_chooser_dialog = self.get_filechooser_dialog()
-        file_chooser_dialog.run()
+        file_chooser_dialog.show()
 
     def on_entry_changed(self, widget):
         """Entry changed callback"""
@@ -122,6 +125,7 @@ class FileChooserEntry(Gtk.Box):
             return
         path = os.path.expanduser(path)
         self.update_completion(path)
+        self.path = path
         if self.warn_if_ntfs and LINUX_SYSTEM.get_fs_type_for_path(path) == "ntfs":
             ntfs_box = Gtk.Box(spacing=6, visible=True)
             warning_image = Gtk.Image(visible=True)
@@ -150,14 +154,14 @@ class FileChooserEntry(Gtk.Box):
             ))
             self.pack_end(non_writable_destination_label, False, False, 10)
 
-    def on_select_file(self, dialog, response):
+    def on_select_file(self, dialog, response, _dialog):
         """FileChooserDialog response callback"""
-        if response == Gtk.ResponseType.OK:
+        if response == Gtk.ResponseType.ACCEPT:
             target_path = dialog.get_filename()
             if target_path:
                 dialog.set_current_folder(target_path)
                 self.entry.set_text(system.reverse_expanduser(target_path))
-        dialog.hide()
+        dialog.destroy()
 
     def update_completion(self, current_path):
         """Update the auto-completion widget with the current path"""
@@ -188,7 +192,6 @@ class FileChooserEntry(Gtk.Box):
 
 
 class Label(Gtk.Label):
-
     """Standardised label for config vboxes."""
 
     def __init__(self, message=None):
@@ -203,7 +206,6 @@ class Label(Gtk.Label):
 
 
 class InstallerLabel(Gtk.Label):
-
     """Label for installer window"""
 
     def __init__(self, message=None):
@@ -216,7 +218,6 @@ class InstallerLabel(Gtk.Label):
 
 
 class VBox(Gtk.Box):
-
     def __init__(self, **kwargs):
         super().__init__(orientation=Gtk.Orientation.VERTICAL, margin_top=18, **kwargs)
 
